@@ -113,19 +113,25 @@ class R3sponse(object):
 		# optionals:
 		# save to log file.
 		save=False,
+		# save errors only (for option 2 only).
+		save_errors=False,
 	):
-		msg = None
+		msg, _error_ = None, False
 		if [message,response] == [None,{}]:
 			raise ValueError("Define either parameter [message:str] or [response:dict].")
 		if response != {}:
 			if response["error"] != None: 
+				_error_ = True
 				msg = f"Error: {response['error']}"
 			else: 
 				msg = response["message"]
 		else: 
 			msg = message
 		print(color.fill(msg))
-		if save: self.__log_to_file__(msg)
+		if save: 
+			self.__log_to_file__(msg)
+		elif save_errors and _error_:
+			self.__log_to_file__(msg)
 
 		#
 	def load_logs(self, format="webserver", options=["webserver", "cli", "array", "string"]):
